@@ -9,6 +9,21 @@ import json
 log = logging.getLogger(__name__)
 
 
+def bakmanager_periodic_backups(conf):
+    """Fetch periodic backups info from bakmanager.io API."""
+    if conf.get("bakmanager_token"):
+        bakmanager_backups_endpoint = conf.get("bakmanager_api", "https://bakmanager.io/api/keys/")
+        r = requests.get(bakmanager_backups_endpoint, auth=(conf.get("bakmanager_token"), ""))
+        r.raise_for_status()
+        for key in r.json().get("_items", []):
+            latest_date = key.get("latest", {}).get("date_human")
+            line = "{key:20} status: {status:5} interval: {interval_human:6} total: {total_size_human:10}".format(**key)
+            line += " latest: {0} ".format(latest_date)
+            log.info(line)
+    else:
+        log.error("No bakmanager_token setting for the current profile.")
+
+
 def bakmanager_hook(conf, backup_data, key=None):
     """First version of a hook for monitoring periodic backups with BakManager
     (https://bakmanager.io).
